@@ -18,6 +18,15 @@ from muntjac.demo.SimpleAddressBook import SimpleAddressBook
 from muntjac.demo.MuntjacTunesLayout import MuntjacTunesLayout
 from muntjac.demo.sampler.SamplerApplication import SamplerApplication
 
+from muntjac.addon.colorpicker.color_picker_application \
+    import ColorPickerApplication
+
+from muntjac.addon.codemirror.code_mirror_application \
+    import CodeMirrorApplication
+
+from muntjac.addon.google_maps.google_map_app \
+    import GoogleMapWidgetApp
+
 from paste.urlmap import URLMap
 from paste.session import SessionMiddleware
 from paste.fileapp import DirectoryApp
@@ -34,6 +43,12 @@ tunes = ApplicationServlet(MuntjacTunesLayout)
 sampler = ApplicationServlet(SamplerApplication,
         widgetset='com.vaadin.demo.sampler.gwt.SamplerWidgetSet')
 
+colorpicker = ApplicationServlet(ColorPickerApplication)
+
+codemirror = ApplicationServlet(CodeMirrorApplication)
+
+googlemaps = ApplicationServlet(GoogleMapWidgetApp)
+
 
 urlmap = URLMap({})
 urlmap['/hello'] = hello
@@ -41,6 +56,9 @@ urlmap['/calc'] = calc
 urlmap['/address'] = address
 urlmap['/tunes'] = tunes
 urlmap['/sampler'] = sampler
+urlmap['/colorpicker'] = colorpicker
+urlmap['/codemirror'] = codemirror
+urlmap['/googlemaps'] = googlemaps
 
 ws_app = DirectoryApp(join(dirname(muntjac.__file__), 'public', 'VAADIN'))
 urlmap['/VAADIN'] = ws_app
